@@ -71,11 +71,13 @@ def asset_url(path):
 def update_usage():
         
         res={}
+        have_change=False
         for user in User.query.all():
             if user.monthly and (datetime.date.today()-user.last_reset_time).days>=30:
                 user.last_reset_time=datetime.date.today()
                 if user.current_usage_GB > user.usage_limit_GB:
                     xray_api.add_client(user.uuid)
+                    have_change=True
                 user.current_usage_GB=0
 
             d = xray_api.get_usage(user.uuid,reset=True)
@@ -88,10 +90,12 @@ def update_usage():
                 user.current_usage_GB += in_gig
             if user.current_usage_GB > user.usage_limit_GB:
                 xray_api.remove_client(user.uuid)
+                have_change=True
                 res[user.uuid]+=" !OUT of USAGE! Client Removed"
                     
         db.session.commit()
-        
+        if have_change:
+            quick_apply_users()
         return {"status": 'success', "comments":res}
         
 
@@ -137,11 +141,17 @@ def get_available_proxies():
     
     if not hconfig(ConfigEnum.http_proxy_enable):
         proxies=[c for c in proxies if 'http' != c.l3]
+    
+    if not Domain.query.filter(Domain.mode==DomainType.cdn).first():
+        proxies=[c for c in proxies if c.cdn!="CDN"]
     return proxies
 
+def quick_apply_users():
+    exec_command("/opt/hiddify-config/install.sh apply_users &")
 
-def flash_config_success(full_install=False):
-    url=url_for('admin.Actions:'+('reinstall' if full_install else 'apply_configs'))
+
+def flash_config_success(full_install=False,domain_changed=True):
+    url=url_for('admin.Actions:reinstall',complete_install=full_install,domain_changed=domain_changed)
     apply_btn=f"<a href='{url}' class='btn btn-primary form_post'>"+_("admin.config.apply_configs")+"</a>"
     flash((_('config.validation-success',link=apply_btn)), 'success')
 
